document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');

  mobileMenu.addEventListener('click', () => {
    navLinks.classList.toggle('active');
    mobileMenu.classList.toggle('active');
  });

  // Smooth scrolling for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      if (target) {
        window.scrollTo({
          top: target.offsetTop - 80,
          behavior: 'smooth'
        });
        navLinks.classList.remove('active');
      }
    });
  });

  // Interactive prototype demo
  const startDemo = document.getElementById('startDemo');
  const gestureTracker = document.querySelector('.gesture-tracker');

  if (startDemo && gestureTracker) {
    startDemo.addEventListener('click', () => {
      startDemo.textContent = 'Demo Active';
      startDemo.classList.add('active');
      
      // Simple gesture tracking animation
      let trackerDot = document.createElement('div');
      trackerDot.classList.add('tracker-dot');
      gestureTracker.appendChild(trackerDot);

      const trackMouse = (e) => {
        const rect = gestureTracker.getBoundingClientRect();
        const x = e.clientX - rect.left;
        const y = e.clientY - rect.top;
        
        trackerDot.style.transform = `translate(${x}px, ${y}px)`;
      };

      gestureTracker.addEventListener('mousemove', trackMouse);
    });
  }

  // Animate statistics when in view
  const observerOptions = {
    threshold: 0.5,
    rootMargin: '0px'
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('animate');
      }
    });
  }, observerOptions);

  document.querySelectorAll('.stat-card').forEach(card => {
    observer.observe(card);
  });
});
